const path = require("path");

module.exports = grunt => {
    grunt.initConfig({
        pkg: grunt.file.readJSON("package.json"),
        clean: {
            default: ["dist/"],
        },
        cssmin: {
            target: {
                files: {
                    "dist/bundle.css": "src/main/css/main.css",
                },
            },
        },
        focus: {
            dev: {
                include: ["css", "js"],
            },
        },
        webpack: {
            options: {
                entry: "./src/main/js/main.js",
                module: {
                    rules: [
                        {
                            test: /\.js$/i,
                            exclude: /node_modules/,
                        },
                    ],
                },
                resolve: {
                    extensions: [".js"],
                },
                output: {
                    library: "fwdekker-template",
                    libraryTarget: "umd",
                    filename: "bundle.js",
                    path: path.resolve(__dirname, "dist"),
                }
            },
            dev: {
                mode: "development",
                devtool: "inline-source-map",
            },
            deploy: {
                mode: "production",
            },
        },
        watch: {
            css: {
                files: ["src/main/**/*.css"],
                tasks: ["cssmin"],
            },
            js: {
                files: ["src/main/**/*.js"],
                tasks: ["webpack:dev"],
            },
        },
    });

    grunt.loadNpmTasks("grunt-contrib-clean");
    grunt.loadNpmTasks("grunt-contrib-cssmin");
    grunt.loadNpmTasks("grunt-contrib-watch");
    grunt.loadNpmTasks("grunt-focus");
    grunt.loadNpmTasks("grunt-webpack");

    grunt.registerTask("dev", ["webpack:dev", "cssmin"]);
    grunt.registerTask("dev:server", ["dev", "focus:dev"]);
    grunt.registerTask("deploy", ["webpack:deploy", "cssmin"]);

    grunt.registerTask("default", ["dev"]);
};
